/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;

/**
 * PN2 レンデラーは、カラムのデータを品番情報(１１桁の文字列を３-５-３)に対して、
 * それぞれ、"PN_1","PN_2","PN_3"というクラスを付加します。
 * これにより、真ん中の部分だけの色を変えたりすることができます。
 *
 * このクラスは、不変オブジェクトとして、共有されます。
 *
 * @og.group データ表示
 *
 * @version  5.0
 * @author	 Hiroki Nakamura
 * @since    JDK5.0,
 */
public class Renderer_PN2 extends AbstractRenderer {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.0.4.0 (2014/11/28)" ;

	private static final CellRenderer dbCell = new Renderer_PN2() ;

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 * @og.rtnNotNull
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return dbCell;
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) null値対応
	 *
	 * @param	value 入力値
	 *
	 * @return	データの表示用文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final String value ) {
		String rtn = ( value == null ) ? "" : value;
		if( rtn.length() >= 10 ) {
			rtn = "<span class=\"PN_1\">" + rtn.substring( 0, 3 ) + "</span>"
				+ "<span class=\"PN_2\">" + rtn.substring( 3, 8 ) + "</span>"
				+ "<span class=\"PN_3\">" + rtn.substring( 8 )    + "</span>" ;
		}
		return rtn;
	}

	/**
	 * データ出力用の文字列を作成します。
	 * ファイル等に出力する形式を想定しますので、HTMLタグを含まない
	 * データを返します。
	 * 基本は、#getValue( String ) をそのまま返します。
	 *
	 * @og.rev 6.0.4.0 (2014/11/28) データ出力用のレンデラー
	 *
	 * @param   value 入力値
	 *
	 * @return  データ出力用の文字列
	 * @og.rtnNotNull
	 * @see		#getValue( String )
	 */
	@Override
	public String getWriteValue( final String value ) {
		String rtn = ( value == null ) ? "" : value;
		if( rtn.length() >= 10 ) {
			rtn = rtn.substring( 0, 3 ) + "-" + rtn.substring( 3, 8 ) + "-" + rtn.substring( 8 ) ;
		}
		return rtn;
	}
}
